@@ -13,16 +13,15 @@ def obtenirConfigurationsProducteurDepuisVariablesEnvironnement():
     }
     if 'KAFKA_SECURITY_PROTOCOL' in os.environ:
         config_kafka['security.protocol'] = os.environ['KAFKA_SECURITY_PROTOCOL']
-    if 'KAFKA_SSL_TRUSTSTORE_LOCATION' in os.environ:
-        config_kafka['ssl.truststore.location'] = os.environ['KAFKA_SSL_TRUSTSTORE_LOCATION']
-    if 'KAFKA_SSL_TRUSTSTORE_PASSWORD' in os.environ:
-        config_kafka['ssl.truststore.password'] = os.environ['KAFKA_SSL_TRUSTSTORE_PASSWORD']
-    if 'KAFKA_SSL_KEYSTORE_LOCATION' in os.environ:
-        config_kafka['ssl.keystore.location'] = os.environ['KAFKA_SSL_KEYSTORE_LOCATION']
-    if 'KAFKA_SSL_KEYSTORE_PASSWORD' in os.environ:
-        config_kafka['ssl.keystore.password'] = os.environ['KAFKA_SSL_KEYSTORE_PASSWORD']
+    if 'KAFKA_SSL_CA_LOCATION' in os.environ:
+        config_kafka['ssl.ca.location'] = os.environ['KAFKA_SSL_CA_LOCATION']
+    if 'KAFKA_SSL_CERTIFICATE_LOCATION' in os.environ:
+        config_kafka['ssl.certificate.location'] = os.environ['KAFKA_SSL_CERTIFICATE_LOCATION']
+    if 'KAFKA_SSL_KEY_LOCATION' in os.environ:
+        config_kafka['ssl.key.location'] = os.environ['KAFKA_SSL_KEY_LOCATION']
     if 'KAFKA_SSL_KEY_PASSWORD' in os.environ:
         config_kafka['ssl.key.password'] = os.environ['KAFKA_SSL_KEY_PASSWORD']    
+
     return config_kafka    
 
 def creerProducteur(config):
